referrerpolicy=no-referrer-when-downgrade

FrameTraceInfo

Trait FrameTraceInfo 

pub trait FrameTraceInfo {
    // Required methods
    fn gas_left(&self) -> u64;
    fn weight_consumed(&self) -> Weight;
    fn last_frame_output(&self) -> Bytes;
}
Interface to provide frame trace information for the current execution frame.

Required Methods

fn gas_left(&self) -> u64

Get the amount of gas remaining in the current frame.

fn weight_consumed(&self) -> Weight

Returns how much weight was spent

fn last_frame_output(&self) -> Bytes

Get the output from the last frame.

Implementors