pub trait EVMFrameTraceInfo: FrameTraceInfo {
// Required methods
fn memory_snapshot(&self, limit: usize) -> Vec<Bytes>;
fn stack_snapshot(&self) -> Vec<Bytes>;
}Expand description
Interface to provide EVM-specific trace information for the current execution frame.
Required Methods
Sourcefn memory_snapshot(&self, limit: usize) -> Vec<Bytes>
fn memory_snapshot(&self, limit: usize) -> Vec<Bytes>
Get a snapshot of the memory at this point in execution.
Parameters
limit: Maximum number of memory words to capture.
Sourcefn stack_snapshot(&self) -> Vec<Bytes>
fn stack_snapshot(&self) -> Vec<Bytes>
Get a snapshot of the stack at this point in execution.